@@ -24,7 +24,7 @@
 ScreenSaverComponent::ScreenSaverComponent( TQObject *parent)
  : Component(parent)
 {
-qWarning("ScreenSaverComponent::ScreenSaverComponent");
+tqWarning("ScreenSaverComponent::ScreenSaverComponent");
     connect(&m_timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotPreviewStarted()));
 }
 
